.. timmy documentation master file, created by
   sphinx-quickstart on Fri Dec 18 10:41:57 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to timmy's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   specification
   configuration
   usage
   cli
   tools
   exitcodes

Indices and tables
==================

..
  * :ref:`genindex`
  * :ref:`modindex`
  * :ref:`search`
